# TAP-Consumer CHANGELOG
## 0.0.6 (2024-10-20)


### Fixes


* fix: lint — rjdbcm <rjdbcm@outlook.com>
([`97d4e0a`](https://github.com/OZI-Project/TAP-Consumer/commit/97d4e0aac83a0a76ad5ef7922db445cf8f1f6e60))

* fix: suppress comments — rjdbcm <rjdbcm@outlook.com>
([`9994cea`](https://github.com/OZI-Project/TAP-Consumer/commit/9994cea5f721725b35dcff9e7c450f0e726e40d1))

## 0.0.5 (2024-10-20)


### Fixes


* fix: correct import name — rjdbcm <rjdbcm@outlook.com>
([`c05bd25`](https://github.com/OZI-Project/TAP-Consumer/commit/c05bd25c0333f80b7124c4d6d32a7f28121f2a07))

* fix: correct import name — rjdbcm <rjdbcm@outlook.com>
([`2b43d66`](https://github.com/OZI-Project/TAP-Consumer/commit/2b43d66acfe119a8601dd7d706d2d1fd2eac9005))

* fix: sync stubs — rjdbcm <rjdbcm@outlook.com>
([`41a3ac4`](https://github.com/OZI-Project/TAP-Consumer/commit/41a3ac4482b3013ef8ea4053c5f66c75ca85c08a))

* fix: lint — rjdbcm <rjdbcm@outlook.com>
([`1bc077b`](https://github.com/OZI-Project/TAP-Consumer/commit/1bc077b5053c2fce230dc95e04f5d93c0858c6f7))

* fix: subtests ignored — rjdbcm <rjdbcm@outlook.com>
([`6b63a42`](https://github.com/OZI-Project/TAP-Consumer/commit/6b63a4252b6014fb28a1ab41270c4e34fed67a9d))

* fix: update __init__.pyi to include MIT notice — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`dd65042`](https://github.com/OZI-Project/TAP-Consumer/commit/dd650429062d16865f7dae253f323d40d20ff552))


### Performance improvements


* perf: add test — rjdbcm <rjdbcm@outlook.com>
([`5c16443`](https://github.com/OZI-Project/TAP-Consumer/commit/5c16443d2e18e140fb80b34e69f4eece2e8157b2))


### Unknown


* Update README — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8e9876f`](https://github.com/OZI-Project/TAP-Consumer/commit/8e9876f9897b14221fe0033de89d2237652eb6c8))

* Create CODE_OF_CONDUCT.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`fdba985`](https://github.com/OZI-Project/TAP-Consumer/commit/fdba98539ea17fcd73d3684369695afbd8feb871))

* Update README — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d7b1275`](https://github.com/OZI-Project/TAP-Consumer/commit/d7b12755ae6418528bb6684db8ecab3d53491d49))

* Update LICENSE.txt — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d614ae5`](https://github.com/OZI-Project/TAP-Consumer/commit/d614ae5f17c642f0e74c70df68dbe349bedc9ef1))

* Update LICENSE.txt — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`2531a3b`](https://github.com/OZI-Project/TAP-Consumer/commit/2531a3b7bbb8b34f79bdb33aed7ee2c62f29ccd1))

* Update LICENSE.txt — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`177a63d`](https://github.com/OZI-Project/TAP-Consumer/commit/177a63d215ad82357ca1c9bf51cf3e57201f868e))

* Update LICENSE.txt — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`87d9d9d`](https://github.com/OZI-Project/TAP-Consumer/commit/87d9d9d7c358a95e7e435a37e8e851c7d438b654))

## 0.0.4 (2024-10-18)


### Fixes


* fix: no longer print TAP version in summary — rjdbcm <rjdbcm@outlook.com>
([`1ae30bc`](https://github.com/OZI-Project/TAP-Consumer/commit/1ae30bc41b110c8c29cfc60749a15f2d2433229b))

* fix: add support for subtests — rjdbcm <rjdbcm@outlook.com>
([`cb4e572`](https://github.com/OZI-Project/TAP-Consumer/commit/cb4e5725f6a8a032a77f670d48c65251e1ac9852))


### Performance improvements


* perf: add stubs — rjdbcm <rjdbcm@outlook.com>
([`6ab1b0b`](https://github.com/OZI-Project/TAP-Consumer/commit/6ab1b0b43b9ed848448b7d8ecb13596acdfcf211))

* perf: add docstrings — rjdbcm <rjdbcm@outlook.com>
([`2400dde`](https://github.com/OZI-Project/TAP-Consumer/commit/2400dde14e2a43d9d4a82a3a7e8ac0326543a4c5))

* perf: refactor to allow method chaining — rjdbcm <rjdbcm@outlook.com>
([`057c5d0`](https://github.com/OZI-Project/TAP-Consumer/commit/057c5d0ed4e8fd894f4cffff149a02516fee4304))

## 0.0.3 (2024-10-17)


### Fixes


* fix: bail out is now caseless — rjdbcm <rjdbcm@outlook.com>
([`eb7b17e`](https://github.com/OZI-Project/TAP-Consumer/commit/eb7b17ec26b1d713fc5f9f396b5c1a6ba40720bc))

## 0.0.2 (2024-10-17)


### Fixes


* fix: stop dumping raw test results — rjdbcm <rjdbcm@outlook.com>
([`8d67172`](https://github.com/OZI-Project/TAP-Consumer/commit/8d67172f4718643e7680b19f0737c287927348a3))


### Performance improvements


* perf: add YAML diagnostics summary — rjdbcm <rjdbcm@outlook.com>
([`7a1f27a`](https://github.com/OZI-Project/TAP-Consumer/commit/7a1f27a51bb171e28ab26ea1c798b143709dc609))

## 0.0.1 (2024-10-16)


### Fixes


* fix: broken symlink — rjdbcm <rjdbcm@outlook.com>
([`f32e67b`](https://github.com/OZI-Project/TAP-Consumer/commit/f32e67ba0a07551e0c36ff791809369b373363a2))

* fix: add MIT notice — rjdbcm <rjdbcm@outlook.com>
([`1e91d29`](https://github.com/OZI-Project/TAP-Consumer/commit/1e91d2948926a26b343e866b473c2b58d188c5f6))

* fix: dowload link — rjdbcm <rjdbcm@outlook.com>
([`6f5a145`](https://github.com/OZI-Project/TAP-Consumer/commit/6f5a14593b959a26462a58c67d700ef267e540de))

* fix: add PyYAML as a dependency — rjdbcm <rjdbcm@outlook.com>
([`85ad9a0`](https://github.com/OZI-Project/TAP-Consumer/commit/85ad9a0826990c6da1ccfd39bf99dae4b2f82b37))


### Performance improvements


* perf: clean up code — rjdbcm <rjdbcm@outlook.com>
([`16721f1`](https://github.com/OZI-Project/TAP-Consumer/commit/16721f1cd280af292237e09dde1383929189db0e))

* perf: clean up code — rjdbcm <rjdbcm@outlook.com>
([`6928f06`](https://github.com/OZI-Project/TAP-Consumer/commit/6928f06be492789a2449ff088ebfc80b3ab0bd81))

* perf: clean up code — rjdbcm <rjdbcm@outlook.com>
([`a249968`](https://github.com/OZI-Project/TAP-Consumer/commit/a2499682a0affcb88e892cd9b17138bfa6cc4ba4))

* perf: add tests — rjdbcm <rjdbcm@outlook.com>
([`b7e0be3`](https://github.com/OZI-Project/TAP-Consumer/commit/b7e0be36a3a7f56ff4f49df5a5a24956824d88cd))

* perf: initial commit — rjdbcm <rjdbcm@outlook.com>
([`52ee1f1`](https://github.com/OZI-Project/TAP-Consumer/commit/52ee1f17fecc982da3dcd5ed8fab40f28eda6ce5))


### Unknown


* Update README.rst — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6198307`](https://github.com/OZI-Project/TAP-Consumer/commit/6198307048b4004552ecd6cc9ad964760bcea792))


## 0.0.0 (2024-10-15)

### :tada:

* :tada:: Initialized TAP-Consumer with ``ozi-new``.

```sh
ozi-new project --name TAP-Consumer --github-harden-runner --github-harden-runner --enable-uv --enable-uv --no-strict --no-strict --summary 'Parses and serializes Test Anything Protocol output.' --keywords TAP,testing,unittest --home-page https://oziproject.dev --author 'Eden Ross Duff MSc' --author-email help@oziproject.dev --license 'OSI Approved :: Apache Software License' --license-expression 'Apache-2.0 WITH LLVM-exception' --requires-dist pyparsing --requires-dist prompt-toolkit
```